<?php

namespace T3SEO\Widont\Hook;

class Widont implements \TYPO3\CMS\Frontend\ContentObject\ContentObjectStdWrapHookInterface {

	/**
	 * @var bool internally used to prevent an infinite loop of stdWraps
	 */
	private static $preventInifiniteRecursion = FALSE;

	/**
	 * Hook for modifying $content before core's stdWrap does anything
	 *
	 * @param string $content Input value undergoing processing in this function. Possibly substituted by other values fetched from another source.
	 * @param array $configuration TypoScript stdWrap properties
	 * @param \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer $parentObject Parent content object
	 * @return string Further processed $content
	 */
	public function stdWrapPreProcess($content, array $configuration, \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer &$parentObject) {
		return $content;
	}

	/**
	 * Hook for modifying $content after core's stdWrap has processed setContentToCurrent, setCurrent, lang, data, field, current, cObject, numRows, filelist and/or preUserFunc
	 *
	 * @param string $content Input value undergoing processing in this function. Possibly substituted by other values fetched from another source.
	 * @param array $configuration TypoScript stdWrap properties
	 * @param \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer $parentObject Parent content object
	 * @return string Further processed $content
	 */
	public function stdWrapOverride($content, array $configuration, \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer &$parentObject) {
		return $content;
	}

	/**
	 * Hook for modifying $content after core's stdWrap has processed override, preIfEmptyListNum, ifEmpty, ifBlank, listNum, trim and/or more (nested) stdWraps
	 *
	 * @param string $content Input value undergoing processing in this function. Possibly substituted by other values fetched from another source.
	 * @param array $configuration TypoScript "stdWrap properties".
	 * @param \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer $parentObject Parent content object
	 * @return string Further processed $content
	 */
	public function stdWrapProcess($content, array $configuration, \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer &$parentObject) {
		if (self::$preventInifiniteRecursion) {
			return $content;
		}
		self::$preventInifiniteRecursion = TRUE;
		$applyWidont = $parentObject->stdWrap($configuration['widont'], $configuration['widont.']);
		self::$preventInifiniteRecursion = FALSE;
		if ($applyWidont) {
			if (
				isset($configuration['widont.']) &&
				(
					isset($configuration['widont.']['splitParagraphs']) ||
					isset($configuration['widont.']['splitParagraphs.'])
				)
			) {
				$splitCharacter = $parentObject->stdWrap($configuration['widont.']['splitParagraphs'], $configuration['widont.']['splitParagraphs.']);
				$paragraphs = explode($splitCharacter, $content);
			} else {
				$splitCharacter = '';
				$paragraphs = array($content);
			}
			$widontedParagraphs = array();
			foreach($paragraphs as $paragraph) {
				$paragraph = rtrim($paragraph);
				$space = strrpos($paragraph, ' ');
				if ($space !== FALSE) {
					$paragraph = substr($paragraph, 0, $space) . '&nbsp;' . substr($paragraph, $space + 1);
				}
				$widontedParagraphs[] = $paragraph;
			}
			$content = join($splitCharacter, $widontedParagraphs);
		}
		return $content;
	}

	/**
	 * Hook for modifying $content after core's stdWrap has processed anything but debug
	 *
	 * @param string $content Input value undergoing processing in this function. Possibly substituted by other values fetched from another source.
	 * @param array $configuration TypoScript stdWrap properties
	 * @param \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer $parentObject Parent content object
	 * @return string Further processed $content
	 */
	public function stdWrapPostProcess($content, array $configuration, \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer &$parentObject) {
		return $content;
	}

}
